% WARNING: Running this code removes all variables from the current
% workspace, and closes current figures.
clear all
close all
home

% Modified by Jiayi Sun 2022-06-07
%{
An example MATLAB code for the dataset, Hunter_2016, that includes more than just
measurements taken at ambient pressure, so there are upswept and
downswept measurements. This example code plots the mean ambient
absorbance, the mean absorbance at the positive tail with a downswept 
sweep direction, and the mean absorbance at TPP with a downswept sweep direction. 
It demonstrates how to split up the data based on the age of the
subjects to create a plot that shows the mean ambient absorbance for
different age groups. This example code demonstrates how to plot the data
when there are multiple sessions. 

Made with MATLAB R2022a
Please install Statistics Toolbox to use some functions inside the code.

PROGRAM STRUCTURE: first ambient absorbance, next downswept positive tail absorbance,
last downswept tpp absorbance. At the very end of the code is where everything is plotted.
%}

%%

% Load in tables from database via MySQL
% Note: file name should match the file name you saved on your computer
data = readtable('WAI_Measurements_2022-06-06.csv');
Subjects_Table = readtable('WAI_Subjects_2022-06-06.csv');


% Only use PI we are checking
PI = 'Hunter_2016';
data=data(strcmp(data.Identifier, PI),:);
Subjects_Table = Subjects_Table(strcmp(Subjects_Table.Identifier, PI),:);


% Get frequencies
Frequency = unique(data.Frequency);
% Get subject numbers and the number of subjects
SubjectNumbers=unique(data.SubjectNumber);
NumberSubjects=length(SubjectNumbers);

% Make sure number of subjects is correct from subjects table, should be 182
NumSubs = length(unique(Subjects_Table.SubjectNumber)); %it's 182, so it's correct

%%

% AMBIENT ABSORBANCE
% Create table of 0, 1, 6, 9, and 12 month infants separately
% also have only ambient measurements in these tables

% Get the rows from the table that include subjects whose age is 0 
% And where the measurements are taken at ambient pressure
data_rows = (data.Age)<=(0) & data.PressureCanal==0;
% Create a table with only the specific rows
data0month = data(data_rows,:);
% Get the subject numbers and number of subjects of the data0month dataset
SubjectNumbers0 = unique(data0month.SubjectNumber);
NumberSubjects0 = length(unique(data0month.SubjectNumber));

% Repeat the same process above but for subjects aged between 1 and 2 months
data_rows = (data.Age)<(2/12) & (data.Age)>=(1/12) & data.PressureCanal==0;
data1month = data(data_rows,:);
SubjectNumbers1 = unique(data1month.SubjectNumber);
NumberSubjects1 = length(SubjectNumbers1);

% Repeat the same process above but for subjects aged between 6 and 7 months
data_rows = (data.Age)<(7/12) & (data.Age)>=(6/12) & data.PressureCanal==0;
data6month = data(data_rows,:);
SubjectNumbers6 = unique(data6month.SubjectNumber);
NumberSubjects6 = length(SubjectNumbers6);

% Repeat the same process above but for subjects aged between 9 and 10 months
data_rows = (data.Age)<(10/12) & (data.Age)>=(9/12) & data.PressureCanal==0;
data9month = data(data_rows,:);
SubjectNumbers9 = unique(data9month.SubjectNumber);
NumberSubjects9 = length(SubjectNumbers9);

% Repeat the same process above but for subjects aged between 12 and 13 months
data_rows = (data.Age)<(13/12) & (data.Age)>=(12/12) & data.PressureCanal==0;
data12month = data(data_rows,:);
SubjectNumbers12 = unique(data12month.SubjectNumber);
NumberSubjects12 = length(SubjectNumbers12);


% Get mean ambient absorbance ready to plot for each age group

% Get mean ambient absorbance for 0 month olds subjects over each frequency
AmbAbs0 = [];
% Index loops through each age 0 subject number
for currentSub_index = 1:NumberSubjects0
    % Find rows of each subject number
    ambSub_row = find(data0month.SubjectNumber==SubjectNumbers0(currentSub_index));
    % Create a table of the subject's data each round of the for loop
    ambientSubdata0 = data0month(ambSub_row,:);
    
    AmbAbsorbanceSub0 = [];
    % Go through each frequency
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        ambFreq_row = find(ambientSubdata0.Frequency==Frequency(currentFreq_index));
        % Create an array for each subject of their absorbance 
        AmbAbsorbanceSub0 = [AmbAbsorbanceSub0; ambientSubdata0.Absorbance(ambFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_AmbSubAbs0 = nanmean(AmbAbsorbanceSub0,2);
    % Create array of the averages of each subject
    AmbAbs0 = [AmbAbs0; mean_AmbSubAbs0.'];
end
% Get the mean of each subject's mean:
mean_AmbAbs0 = nanmean(AmbAbs0)';


% Get mean ambient absorbance for 1 month olds subjects over each frequency
AmbAbs1 = [];
% Index loops through each age 1 month subject number
for currentSub_index = 1:NumberSubjects1
    %find rows of each subject number
    ambSub_row = find(data1month.SubjectNumber==SubjectNumbers1(currentSub_index));
    %create a table of the subject's data each round of the for loop
    ambientSubdata1 = data1month(ambSub_row,:);
    
    AmbAbsorbanceSub1 = [];
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        ambFreq_row = find(ambientSubdata1.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        AmbAbsorbanceSub1 = [AmbAbsorbanceSub1; ambientSubdata1.Absorbance(ambFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_AmbSubAbs1 = nanmean(AmbAbsorbanceSub1,2);
    % Create array of the averages of each subject
    AmbAbs1 = [AmbAbs1; mean_AmbSubAbs1.'];
end
% Get the mean of each subject's mean:
mean_AmbAbs1 = nanmean(AmbAbs1)';


% Get mean ambient absorbance for 6 month olds subjects over each frequency
AmbAbs6 = [];
% Index loops through each age 6 months subject number
for currentSub_index = 1:NumberSubjects6
    % Find rows of each subject number
    ambSub_row = find(data6month.SubjectNumber==SubjectNumbers6(currentSub_index));
    % Create a table of the subject's data each round of the for loop
    ambientSubdata6 = data6month(ambSub_row,:);
    
    AmbAbsorbanceSub6 = [];
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        ambFreq_row = find(ambientSubdata6.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        AmbAbsorbanceSub6 = [AmbAbsorbanceSub6; ambientSubdata6.Absorbance(ambFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_AmbSubAbs6 = nanmean(AmbAbsorbanceSub6,2);
    % Create array of the averages of each subject
    AmbAbs6 = [AmbAbs6; mean_AmbSubAbs6.'];
end
% Get the mean of each subject's mean:
mean_AmbAbs6 = nanmean(AmbAbs6)';

% Get mean ambient absorbance for  9 month olds subjects over each frequency
AmbAbs9 = [];
% Index loops through each age 9 months subject number
for currentSub_index = 1:NumberSubjects9
    % Find rows of each subject number
    ambSub_row = find(data9month.SubjectNumber==SubjectNumbers9(currentSub_index));
    % Create a table of the subject's data each round of the for loop
    ambientSubdata9 = data9month(ambSub_row,:);
    
    AmbAbsorbanceSub = [];
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        ambFreq_row = find(ambientSubdata9.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        AmbAbsorbanceSub = [AmbAbsorbanceSub; ambientSubdata9.Absorbance(ambFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_AmbSubAbs9 = nanmean(AmbAbsorbanceSub,2);
    % Create array of the averages of each subject
    AmbAbs9 = [AmbAbs9; mean_AmbSubAbs9.'];
end
% Get the mean of each subject's mean:
mean_AmbAbs9 = nanmean(AmbAbs9)';


% Get mean ambient absorbance for 12 month olds subjects over each frequency
AmbAbs12 = [];
% Index loops through each age 12 month subject number
for currentSub_index = 1:NumberSubjects12
    % Find rows of each subject number
    ambSub_row = find(data12month.SubjectNumber==SubjectNumbers12(currentSub_index));
    % Create a table of the subject's data each round of the for loop
    ambientSubdata12 = data12month(ambSub_row,:);
    
    AmbAbsorbanceSub12 = [];
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        ambFreq_row = find(ambientSubdata12.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        AmbAbsorbanceSub12 = [AmbAbsorbanceSub12; ambientSubdata12.Absorbance(ambFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_AmbSubAbs12 = nanmean(AmbAbsorbanceSub12,2);
    % Create array of the averages of each subject
    AmbAbs12 = [AmbAbs12; mean_AmbSubAbs12.'];
end
% Get the mean of each subject's mean:
mean_AmbAbs12 = nanmean(AmbAbs12)';

%%

% DOWNSWEPT ABSORBANCE PT
% Create table of 0, 1, 6, 9, and 12 month infants separately
% Also have only DOWNSWEPT measurements in these tables positive tail

% Get the rows from the table that include subjects whose age is 0 
% And where the measurements are downswept and at the positive tail, 
% which is +200 data. 
data_rows = (data.Age)<=(0) & strcmp(data.SweepDirection,'Downswept') & data.PressureCanal == 200;
% Create a table with these rows
data0monthDPT = data(data_rows,:);
% % Get the subject numbers and number of subjects of the data0monthDPT dataset
SubjectNumbers0DPT = unique(data0monthDPT.SubjectNumber);
NumberSubjects0DPT = length(unique(data0monthDPT.SubjectNumber));

% Repeat the same process above but for subjects aged between 1 and 2 months
data_rows = (data.Age)<(2/12) & (data.Age)>=(1/12) & strcmp(data.SweepDirection,'Downswept') & data.PressureCanal == 200;
data1monthDPT = data(data_rows,:);
SubjectNumbers1DPT = unique(data1monthDPT.SubjectNumber);
NumberSubjects1DPT = length(SubjectNumbers1DPT);

% Repeat the same process above but for subjects aged between 6 and 7 months
data_rows = (data.Age)<(7/12) & (data.Age)>=(6/12) & strcmp(data.SweepDirection,'Downswept') & data.PressureCanal == 200;
data6monthDPT = data(data_rows,:);
SubjectNumbers6DPT = unique(data6monthDPT.SubjectNumber);
NumberSubjects6DPT = length(SubjectNumbers6DPT);

% Repeat the same process above but for subjects aged between 9 and 10 months
data_rows = (data.Age)<(10/12) & (data.Age)>=(9/12) & strcmp(data.SweepDirection,'Downswept') & data.PressureCanal == 200;
data9monthDPT = data(data_rows,:);
SubjectNumbers9DPT = unique(data9monthDPT.SubjectNumber);
NumberSubjects9DPT = length(SubjectNumbers9DPT);

% Repeat the same process above but for subjects aged between 12 and 13 months
data_rows = (data.Age)<(13/12) & (data.Age)>=(12/12) & strcmp(data.SweepDirection,'Downswept') & data.PressureCanal == 200;
data12monthDPT = data(data_rows,:);
SubjectNumbers12DPT = unique(data12monthDPT.SubjectNumber);
NumberSubjects12DPT = length(SubjectNumbers12DPT);


% Get mean downswept absorbance at PT ready to plot for each age group

% Get mean DOWNSWEPT PT absorbance for 0 month olds subjects over each frequency
DPTAbs0 = [];
% Index loops through each age 0 subject number
for currentSub_index = 1:NumberSubjects0DPT
    % Find rows of each subject number
    DPTSub_row = find(data0monthDPT.SubjectNumber==SubjectNumbers0DPT(currentSub_index));
    % create a table of the subject's data each round of the for loop
    DPTSubdata0 = data0monthDPT(DPTSub_row,:);
    
    DPTAbsorbanceSub0 = [];
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        DPTFreq_row = find(DPTSubdata0.Frequency==Frequency(currentFreq_index));
        DPTAbsorbanceSub0 = [DPTAbsorbanceSub0; DPTSubdata0.Absorbance(DPTFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_DPTSubAbs0 = nanmean(DPTAbsorbanceSub0,2);
    % Create array of the averages of each subject
    DPTAbs0 = [DPTAbs0; mean_DPTSubAbs0.'];
end
% Get the mean of each subject's mean:
mean_DPTAbs0 = nanmean(DPTAbs0)';



% Get mean DOWNSWEPT PT absorbance for 1 month olds subjects over each frequency
DPTAbs1 = [];
% Index loops through each age 1 month subject number
for currentSub_index = 1:NumberSubjects1DPT
    % Find rows of each subject number
    DPTSub_row = find(data1monthDPT.SubjectNumber==SubjectNumbers1DPT(currentSub_index));
    % Create a table of each subject's data each round of the for loop
    DPTSubdata1 = data1monthDPT(DPTSub_row,:);
    
    DPTAbsorbanceSub1 = [];
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        DPTFreq_row = find(DPTSubdata1.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        DPTAbsorbanceSub1 = [DPTAbsorbanceSub1; DPTSubdata1.Absorbance(DPTFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_DPTSubAbs1 = nanmean(DPTAbsorbanceSub1,2);
    % Create array of the averages of each subject
    DPTAbs1 = [DPTAbs1; mean_DPTSubAbs1.'];
end
% Get the mean of the subjects' means
mean_DPTAbs1 = nanmean(DPTAbs1)';


% Get mean DOWNSWEPT PT absorbance for 6 month olds subjects over each frequency
DPTAbs6 = [];
% Index loops through each age 6 months subject number
for currentSub_index = 1:NumberSubjects6DPT
    % Find rows of each subject number
    DPTSub_row = find(data6monthDPT.SubjectNumber==SubjectNumbers6DPT(currentSub_index));
    % Create a table of the subject's data each round of the for loop
    DPTSubdata6 = data6monthDPT(DPTSub_row,:);
    
    DPTAbsorbanceSub6 = [];
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        DPTFreq_row = find(DPTSubdata6.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        DPTAbsorbanceSub6 = [DPTAbsorbanceSub6; DPTSubdata6.Absorbance(DPTFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_DPTSubAbs6 = nanmean(DPTAbsorbanceSub6,2);
    % Create array of the averages of each subject
    DPTAbs6 = [DPTAbs6; mean_DPTSubAbs6.'];
end
% Get the mean of the subjects' means
mean_DPTAbs6 = nanmean(DPTAbs6)';


% Get mean DOWNSWEPT PT absorbance for 9 month olds subjects over each frequency
DPTAbs9 = [];
% Index loops through each age 9 months subject number
for currentSub_index = 1:NumberSubjects9DPT
    % Find rows of each subject number
    DPTSub_row = find(data9monthDPT.SubjectNumber==SubjectNumbers9DPT(currentSub_index));
    % Create a table of the subject's data each round of the for loop
    DPTSubdata9 = data9monthDPT(DPTSub_row,:);
    
    DPTAbsorbanceSub9 = [];
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        DPTFreq_row = find(DPTSubdata9.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        DPTAbsorbanceSub9 = [DPTAbsorbanceSub9; DPTSubdata9.Absorbance(DPTFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_DPTSubAbs9 = nanmean(DPTAbsorbanceSub9,2);
    %create array of the averages of each subject
    DPTAbs9 = [DPTAbs9; mean_DPTSubAbs9.'];
end
% Get the mean of the subjects' means:
mean_DPTAbs9 = nanmean(DPTAbs9)';


% Get mean DOWNSWEPT PT absorbance for 12 month olds subjects over each frequency
DPTAbs12 = [];
% Index loops through each age 12 months subject number
for currentSub_index = 1:NumberSubjects12DPT
    % Find rows of each subject number
    DPTSub_row = find(data12monthDPT.SubjectNumber==SubjectNumbers12DPT(currentSub_index));
    % Create a table of each subject's data each round of the for loop
    DPTSubdata12 = data12monthDPT(DPTSub_row,:);
    
    DPTAbsorbanceSub12 = [];
    for currentFreq_index=1:length(Frequency)
        % Find rows for the subject number of each frequency
        DPTFreq_row = find(DPTSubdata12.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        DPTAbsorbanceSub12 = [DPTAbsorbanceSub12; DPTSubdata12.Absorbance(DPTFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_DPTSubAbs12 = nanmean(DPTAbsorbanceSub12,2);
    % Create array of the averages of each subject
    DPTAbs12 = [DPTAbs12; mean_DPTSubAbs12.'];
end
% Get the mean of the subjects' means:
mean_DPTAbs12 = nanmean(DPTAbs12)';


%%

% DOWNSWEPT ABSORBANCE TPP
% Create table of 0, 1, 6, 9, and 12 month infants separately
% Also have only DOWNSWEPT measurements in these tables at TPP

% Get the rows from the table that include subjects whose age is 0 and where
% the measurements are downswept and at TPP, so this data can not include
% the data from the PT or NT, as shown. Another option is to put
% data.PressureCanal == data.TPP.
data_rows = (data.Age)<=(0) & strcmp(data.SweepDirection,'Downswept') & data.PressureCanal ~= 200 & data.PressureCanal ~= -300;
% Create a table with these rows
data0monthDTPP = data(data_rows,:);
% Get the subject numbers and number of subjects of the dataset with these
% Specific parameters
SubjectNumbers0DTPP = unique(data0monthDTPP.SubjectNumber);
NumberSubjects0DTPP = length(unique(data0monthDTPP.SubjectNumber));

% Repeat the same process above but for 1 to 2 month subjects
data_rows = (data.Age)<(2/12) & (data.Age)>=(1/12) & strcmp(data.SweepDirection,'Downswept') & data.PressureCanal ~= 200 & data.PressureCanal ~= -300;
data1monthDTPP = data(data_rows,:);
SubjectNumbers1DTPP = unique(data1monthDTPP.SubjectNumber);
NumberSubjects1DTPP = length(SubjectNumbers1DTPP);

% Repeat the same process above but for 6 to 7 month subjects
data_rows = (data.Age)<(7/12) & (data.Age)>=(6/12) & strcmp(data.SweepDirection,'Downswept') & data.PressureCanal ~= 200 & data.PressureCanal ~= -300;
data6monthDTPP = data(data_rows,:);
SubjectNumbers6DTPP = unique(data6monthDTPP.SubjectNumber);
NumberSubjects6DTPP = length(SubjectNumbers6DTPP);

% Repeat the same process above but for 9 to 10 month subjects
data_rows = (data.Age)<(10/12) & (data.Age)>=(9/12) & strcmp(data.SweepDirection,'Downswept') & data.PressureCanal ~= 200 & data.PressureCanal ~= -300;
data9monthDTPP = data(data_rows,:);
SubjectNumbers9DTPP = unique(data9monthDTPP.SubjectNumber);
NumberSubjects9DTPP = length(SubjectNumbers9DTPP);

% Repeat the same process above but for 12 to 13 month subjects
data_rows = (data.Age)<(13/12) & (data.Age)>=(12/12) & strcmp(data.SweepDirection,'Downswept') & data.PressureCanal ~= 200 & data.PressureCanal ~= -300;
data12monthDTPP = data(data_rows,:);
SubjectNumbers12DTPP = unique(data12monthDTPP.SubjectNumber);
NumberSubjects12DTPP = length(SubjectNumbers12DTPP);


% Get mean downswept absorbance at TPP ready to plot for each age group

% Get mean DOWNSWEPT TPP absorbance for 0 month olds subjects over each frequency
DTPPAbs0 = [];
% Index loops through each age 0 subject number
for currentSub_index = 1:NumberSubjects0DTPP
    % Find rows of each subject number
    DTPPSub_row = find(data0monthDTPP.SubjectNumber==SubjectNumbers0DTPP(currentSub_index));
    % Create a table of each subject's data each round of the for loop
    DTPPSubdata0 = data0monthDTPP(DTPPSub_row,:);
    
    DTPPAbsorbanceSub0 = [];
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        DTPPFreq_row = find(DTPPSubdata0.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        DTPPAbsorbanceSub0 = [DTPPAbsorbanceSub0; DTPPSubdata0.Absorbance(DTPPFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_DTPPSubAbs0 = nanmean(DTPPAbsorbanceSub0,2);
    % Create array of the averages of each subject
    DTPPAbs0 = [DTPPAbs0; mean_DTPPSubAbs0.'];
end
% Get the mean of the subjects' means:
mean_DTPPAbs0 = nanmean(DTPPAbs0)';


% Get mean DOWNSWEPT TPP absorbance for  1 month olds subjects over each frequency
DTPPAbs1 = [];
% Index loops through each age 1 month subject number
for currentSub_index = 1:NumberSubjects1DTPP
    % Find rows of each subject number
    DTPPSub_row = find(data1monthDTPP.SubjectNumber==SubjectNumbers1DTPP(currentSub_index));
    % Create a table of each subject's data each round of the for loop
    DTPPSubdata1 = data1monthDTPP(DTPPSub_row,:);
    
    DTPPAbsorbanceSub1 = [];
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        DTPPFreq_row = find(DTPPSubdata1.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        DTPPAbsorbanceSub1 = [DTPPAbsorbanceSub1; DTPPSubdata1.Absorbance(DTPPFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_DTPPSubAbs1 = nanmean(DTPPAbsorbanceSub1,2);
    % Create array of the averages of each subject
    DTPPAbs1 = [DTPPAbs1; mean_DTPPSubAbs1.'];
end
% Get the mean of the subjects' means
mean_DTPPAbs1 = nanmean(DTPPAbs1)';


% Get mean DOWNSWEPT TPP absorbance for 6 month olds subjects over each frequency
DTPPAbs6 = [];
% Index loops through each age 6 months subject number
for currentSub_index=1:NumberSubjects6DTPP
    % Find rows of each subject number
    DTPPSub_row = find(data6monthDTPP.SubjectNumber==SubjectNumbers6DTPP(currentSub_index));
    % Create a table of each subject's data each round of the for loop
    DTPPSubdata6 = data6monthDTPP(DTPPSub_row,:);
    
    DTPPAbsorbanceSub6 = [];
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        DTPPFreq_row = find(DTPPSubdata6.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        DTPPAbsorbanceSub6 = [DTPPAbsorbanceSub6; DTPPSubdata6.Absorbance(DTPPFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_DTPPSubAbs6 = nanmean(DTPPAbsorbanceSub6,2);
    % Create array of the averages of each subject
    DTPPAbs6 = [DTPPAbs6; mean_DTPPSubAbs6.'];
end
% Get the mean of the subjects' means
mean_DTPPAbs6 = nanmean(DTPPAbs6)';


% Get mean DOWNSWEPT TPP absorbance for 9 month olds subjects over each frequency
DTPPAbs9 = [];
% Index loops through each age 9 months subject number
for currentSub_index=1:NumberSubjects9DTPP
    % Find rows of each subject number
    DTPPSub_row = find(data9monthDTPP.SubjectNumber==SubjectNumbers9DTPP(currentSub_index));
    % Create a table of each subject's data each round of the for loop
    DTPPSubdata9 = data9monthDTPP(DTPPSub_row,:);
    
    DTPPAbsorbanceSub9 = [];
    for currentFreq_index = 1:length(Frequency)
        % Find rows for the subject number of each frequency
        DTPPFreq_row = find(DTPPSubdata9.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        DTPPAbsorbanceSub9 = [DTPPAbsorbanceSub9; DTPPSubdata9.Absorbance(DTPPFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_DTPPSubAbs9 = nanmean(DTPPAbsorbanceSub9,2);
    % Create array of the averages of each subject
    DTPPAbs9 = [DTPPAbs9; mean_DTPPSubAbs9.'];
end
% Get the mean of the subjects' means
mean_DTPPAbs9 = nanmean(DTPPAbs9)';


% Get mean DOWNSWEPT TPP absorbance for 12 month olds subjects over each frequency
DTPPAbs12 = [];
% Index loops through each age 12 months subject number
for currentSub_index = 1:NumberSubjects12DTPP
    % Find rows of each subject number
    DTPPSub_row = find(data12monthDTPP.SubjectNumber==SubjectNumbers12DTPP(currentSub_index));
    % Create a table of each subject's data each round of the for loop
    DTPPSubdata12 = data12monthDTPP(DTPPSub_row,:);
    
    DTPPAbsorbanceSub12 = [];
    for currentFreq_index=1:length(Frequency)
        % Find rows for the subject number of each frequency
        DTPPFreq_row = find(DTPPSubdata12.Frequency==Frequency(currentFreq_index));
        % Create an array of the absorbance of each subject
        DTPPAbsorbanceSub12 = [DTPPAbsorbanceSub12; DTPPSubdata12.Absorbance(DTPPFreq_row).'];
    end
    % Get the mean for the subject's absorbance at each frequency
    mean_DTPPSubAbs12 = nanmean(DTPPAbsorbanceSub12,2);
    % Create array of the averages of each subject
    DTPPAbs12 = [DTPPAbs12; mean_DTPPSubAbs12.'];
end
% Get the mean of the subjects' means:
mean_DTPPAbs12 = nanmean(DTPPAbs12)';

%%

% Plot the mean ambient absorbance 
figure(1)
set(gcf, 'Position', [50, 50, 400, 700])
sgtitle('Hunter et al. (2016)', 'FontSize', 20)
subplot(311)
semilogx(Frequency, mean_AmbAbs0, 'b', 'LineWidth', 2)
xlim([100 10000])
ylim([0 1])
xlabel('Frequency (Hz)')
ylabel('Absorbance')
title('Ambient Absorbance')
hold on
semilogx(Frequency, mean_AmbAbs1, 'r', 'LineWidth', 2)
semilogx(Frequency, mean_AmbAbs6, 'k', 'LineWidth', 2)
semilogx(Frequency, mean_AmbAbs9, 'g', 'LineWidth', 2)
semilogx(Frequency, mean_AmbAbs12, 'm', 'LineWidth', 2)
legend('0 months', '1 month', '6 months', '9 months', '12 months', 'Location', 'NorthEastOutside')
hold off

% Plot downswept at pt absorbance
subplot(312)
semilogx(Frequency, mean_DPTAbs0, 'b', 'LineWidth', 2)
xlim([100 10000])
ylim([0 1])
xlabel('Frequency (Hz)')
ylabel('Absorbance')
title('Downswept PT Absorbance')
hold on
semilogx(Frequency, mean_DPTAbs1, 'r', 'LineWidth', 2)
semilogx(Frequency, mean_DPTAbs6, 'k', 'LineWidth', 2)
semilogx(Frequency, mean_DPTAbs9, 'g', 'LineWidth', 2)
semilogx(Frequency, mean_DPTAbs12, 'm', 'LineWidth', 2)
legend('0 months', '1 month', '6 months', '9 months', '12 months', 'Location', 'NorthEastOutside')
hold off

% Plot mean absorbance for downswept at TPP data
subplot(313)
semilogx(Frequency, mean_DTPPAbs0, 'b', 'LineWidth', 2)
xlim([100 10000])
ylim([0 1])
xlabel('Frequency (Hz)')
ylabel('Absorbance')
title('Downswept TPP Absorbance')
hold on
semilogx(Frequency, mean_DTPPAbs1, 'r', 'LineWidth', 2)
semilogx(Frequency, mean_DTPPAbs6, 'k', 'LineWidth', 2)
semilogx(Frequency, mean_DTPPAbs9, 'g', 'LineWidth', 2)
semilogx(Frequency, mean_DTPPAbs12, 'm', 'LineWidth', 2)
legend('0 months', '1 month', '6 months', '9 months', '12 months', 'Location', 'NorthEastOutside')
hold off
